/**
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Licensed under the MIT License.
 */
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
const selenium_webdriver_1 = require("selenium-webdriver");
const by_1 = require("./by");
class AppiumDriver {
    static windowsCapabilities(appName) {
        return {
            browserName: '',
            platformName: 'windows',
            deviceName: 'WindowsPC',
            app: appName
        };
    }
    static createWinAppDriver(appName, url = "http://localhost:4723/wd/hub") {
        return new Promise(resolve => {
            new selenium_webdriver_1.Builder()
                .usingServer(url)
                .withCapabilities(AppiumDriver.windowsCapabilities(appName))
                .build().
                then((driver) => { resolve(new AppiumDriver(driver)); });
        });
    }
    webDriver() {
        return this.driver_;
    }
    constructor(driver) {
        this.driver_ = driver;
    }
    getByAccessibilityId(id, timeout = 0, message = undefined) {
        return this.driver_.wait(selenium_webdriver_1.until.elementLocated(by_1.By.accessibilityId(id)), timeout, message);
    }
    getByName(name, timeout = 0, message = undefined) {
        return this.driver_.wait(selenium_webdriver_1.until.elementLocated(by_1.By.name(name)), timeout, message);
    }
    getById(id, timeout = 0, message = undefined) {
        return this.driver_.wait(selenium_webdriver_1.until.elementLocated(by_1.By.id(id)), timeout, message);
    }
    getByclassName(className, timeout = 0, message = undefined) {
        return this.driver_.wait(selenium_webdriver_1.until.elementLocated(by_1.By.className(className)), timeout, message);
    }
    sleep(ms) {
        return this.driver_.sleep(ms);
    }
    quit() {
        return this.driver_.quit();
    }
}
exports.AppiumDriver = AppiumDriver;
//# sourceMappingURL=appiumdriver.js.map